package pack;
import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;
import java.util.*;

public class AccountApp {
    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";
    Account account;
    private int id;
    private String name, pw;
    private Scanner kb;
    private Dao<Account, Integer> accountDao;

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "Crapshoes1337");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    private void processData() throws Exception {
        kb = new Scanner(System.in);
        int input;
        while(true) {
            mainMenu();
            input = kb.nextInt();
            if (input == 0) break;
            switch (input) {
                case 1: create(); break;
                case 2: read(); break;
                case 3: update(); break;
                case 4: delete(); break;
                default:
                    System.out.println("Not a valid command");
            }
        }
    }

    public void mainMenu() {
        System.out.println("Main menu! options:");
        System.out.println("0.) exit.");
        System.out.println("1.) Create a new user / password");
        System.out.println("2.) Read a user by their ID");
        System.out.println("3.) Update a user's info by their ID");
        System.out.println("4.) Delete a user by their ID");
    }

    public void create() throws Exception {
        System.out.println("Enter a name for new user");
        name = kb.next();
        account = new Account(name);
        accountDao.create(account);
        id = account.getId();
        System.out.println("your account id is " + id);
        System.out.println("Please type a password");
        pw = kb.next();
        account.setPassword(pw);
        accountDao.update(account);
    }

    public void read() throws Exception {
        System.out.println("Enter an ID to read from database");
        id = kb.nextInt();
        System.out.println("User : " + accountDao.queryForId(id).getName() + " found at ID# " + id);
    }

    public void update() throws Exception {
        System.out.println("Enter an ID to change password");
        id = kb.nextInt();
        Account a = accountDao.queryForId(id);
        a.setPassword(setNewPass(a));
        accountDao.update(a);
    }

    public String setNewPass(Account a) {
        System.out.println(a.getName() + " Please enter a new password.");
        return kb.next();
    }

    public void delete() throws Exception {
        System.out.println("enter an ID to delete from user database");
        id = kb.nextInt();
        accountDao.deleteById(id);
        System.out.println("Successfully deleted user @ id: " + id);
    }

    /**
     * Setup our  DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }

}
